DefaultServerConnectionHandler

Struct DefaultServerConnectionHandler 

pub struct DefaultServerConnectionHandler;
Server connection handler that produces a fresh random identity for each handshake, returns no server initial data, and checks the client version against CARGO_PKG_VERSION.