pub type DefaultExecutor = TokioExecutor;Expand description
The default executor type selected by the active feature flag.
Aliased Type
pub struct DefaultExecutor;pub type DefaultExecutor = TokioExecutor;The default executor type selected by the active feature flag.
pub struct DefaultExecutor;