ProbeFlowSender

Trait ProbeFlowSender 

pub trait ProbeFlowSender: Send + Sync {
    // Required method
    fn send_raw<'a>(
        &'a self,
        packet: DynamicByteBuffer,
        target: SocketAddr,
    ) -> Pin<Box<dyn Future<Output = Result<(), SocketError>> + Send + 'a>>;
}
Object-safe interface for sending raw response packets through the flow manager’s socket.

Implemented individually by ServerFlowManager (forwards to send_to) and ClientFlowManager (forwards to send on the connected socket, ignoring target).

Required Methods

fn send_raw<'a>( &'a self, packet: DynamicByteBuffer, target: SocketAddr, ) -> Pin<Box<dyn Future<Output = Result<(), SocketError>> + Send + 'a>>

Send packet as raw bytes to target, bypassing all TYPHOON framing.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: IdentityType + Clone + 'static, AE: AsyncExecutor + 'static> ProbeFlowSender for ClientFlowManager<T, AE>

Source

impl<T: IdentityType + Clone + Eq + Hash + Send + ToString + 'static, AE: AsyncExecutor + 'static> ProbeFlowSender for ServerFlowManager<T, AE>