pub type ProbeFactory<AE> = Arc<dyn Fn() -> Box<dyn ActiveProbeHandler<AE>> + Send + Sync>;Expand description
Factory type for creating active probe handlers.
A simple no-arg closure — manager and settings are supplied to each handler via
ActiveProbeHandler::start after construction, so the factory needs no arguments.
Aliased Type
pub struct ProbeFactory<AE> { /* private fields */ }