Module lib

Module lib 

Macros

basic_router
entrypoint
impl_error_logger
require

Structs

Account
AccountIter
An iterator over account infos, yielding tuples of type T that can be constructed from the current slice of accounts. The iterator advances by consuming the accounts as each item is produced.
Arg
Array
An extractor to handle fixed array contexts.
Error
Interface
InterfaceAccount
Mut
Program
Checks:
ProgramIdArg
Remaining
Signer
System
SystemAccount
UncheckedAccount

Enums

ErrorCode

Traits

CloseAccount
Context
Marker trait for context types. This trait is used only for identification purposes.
CreateAccountCpi
Discriminator
FromAccountInfo
FromRaw
Handler
HandlerContext
LamportsChecked
Owner
Owners
ProgramId
ProgramIds
ReadableAccount
RefFromBytes
ResultExtension
SignerAccount
SignerCheck
SystemCpi
WritableAccount

Functions

discriminator_matches
Discriminator matching with length-optimized comparison strategies. Uses different comparison methods based on discriminator length:
handle

Type Aliases

EntryFn
SignerNoCheck