pub struct Key<T> {
pub name: &'static str,
pub default: T,
}Expand description
A typed setting key that carries its value type at compile time. This ensures type-safe access to settings - you can only get/set values of the correct type for each key.
Fields
name: &'static strdefault: TImplementations