ClientConnectionHandler

Trait ClientConnectionHandler 

pub trait ClientConnectionHandler: Send + Sync {
    // Required methods
    fn initial_data(&self) -> StaticByteBuffer;
    fn version(&self, length: usize) -> StaticByteBuffer;
}
Client-side connection handler: produces client initial data and the version bytes for the handshake.

Required Methods

fn initial_data(&self) -> StaticByteBuffer

Produce initial data to include in the client handshake.

fn version(&self, length: usize) -> StaticByteBuffer

Produce the version bytes to place in the handshake tailer ID field, clamped to length bytes.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors