pub struct DynamicByteBuffer { /* private fields */ }Expand description
A mutable byte buffer with Arc-based reference counting. Send but not Sync - can be moved between threads but not shared. Pool-attached buffers are returned to the pool on drop.
Implementations
Sourceimpl DynamicByteBuffer
impl DynamicByteBuffer
Sourcepub fn copy(&self) -> Self
pub fn copy(&self) -> Self
Convert to an immutable StaticByteBuffer (deep copy, capacity trimmed).
Sourcepub fn to_owned(&self) -> StaticByteBuffer
pub fn to_owned(&self) -> StaticByteBuffer
Convert to an immutable StaticByteBuffer (deep copy, capacity trimmed).
Sourcepub fn before_capacity(&self) -> usize
pub fn before_capacity(&self) -> usize
Returns the number of bytes available for prepending before the current view.
Sourcepub fn append_buf(&self, other: &impl ByteBuffer) -> Self
pub fn append_buf(&self, other: &impl ByteBuffer) -> Self
Append other buffer contents to end. Returns expanded view.
Sourcepub fn prepend_buf(&self, other: &impl ByteBuffer) -> Self
pub fn prepend_buf(&self, other: &impl ByteBuffer) -> Self
Prepend other buffer contents to start. Returns expanded view.