pub struct FakeHeaderConfig { /* private fields */ }Expand description
Fake body generation mode.
Each mode defines how fake body content is generated to pad packets.
Uses Vec
Implementations
Sourceimpl FakeHeaderConfig
impl FakeHeaderConfig
pub fn new(pattern: Vec<FieldTypeHolder>) -> Self
Sourcepub fn random<AE: AsyncExecutor>(settings: &Settings<AE>) -> Self
pub fn random<AE: AsyncExecutor>(settings: &Settings<AE>) -> Self
Create a random header configuration drawn from the default probability distributions.
Includes a header with probability FAKE_HEADER_PROBABILITY; if included, a random number
of fields are packed to fill a length sampled from [FAKE_HEADER_LENGTH_MIN, FAKE_HEADER_LENGTH_MAX].
Each field is independently assigned one of the five FieldType variants weighted by the
FAKE_HEADER_FIELD_WEIGHT_* settings.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn fill(&mut self, buffer: DynamicByteBuffer)