pub trait ClientConnectionHandler: Send + Sync {
// Required methods
fn initial_data(&self) -> StaticByteBuffer;
fn version(&self, length: usize) -> StaticByteBuffer;
}Expand description
Client-side connection handler: produces client initial data and the version bytes for the handshake.
Required Methods
Sourcefn initial_data(&self) -> StaticByteBuffer
fn initial_data(&self) -> StaticByteBuffer
Produce initial data to include in the client handshake.
Sourcefn version(&self, length: usize) -> StaticByteBuffer
fn version(&self, length: usize) -> StaticByteBuffer
Produce the version bytes to place in the handshake tailer ID field, clamped to length bytes.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".